
/*==============================================================================
 *
 * (#)Mailer.java
 * created         2003/02/07
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *==============================================================================
 */

/**
 * Mail form
 */

package com.miami.romeo.internet;

import java.awt.*;
import java.awt.event.*;
import java.util.*;
import java.io.*;

import javax.mail.*;
import javax.mail.internet.*;
import javax.activation.*;

import javax.swing.*;
import javax.swing.border.*;
import javax.swing.text.*;

import com.miami.romeo.config.*;

public class Mailer extends JFrame {

  Utils utils = new Utils();

  // Configuration file
  final private String configFile = System.getProperty("user.home") + 
                                    File.separator + ".romeo4xmame" + 
				    File.separator + "Romeo.ini";

  File config_file = new File(configFile);

  Config conf = new Config(config_file);

  private final String titleMailer = "Mailer";
  private String host;
  private String to = "stef_bol@libero.it";
  private String from;
  private String subject;
  private String messageText;
  private String filename;
  private boolean sessionDebug = false;

  // Filechooser...
  JFileChooser fileChooser = new JFileChooser();

  // Menu Bar
  Border mailerBorder;
  JMenuBar MailerMenuBar = new JMenuBar();

  BorderLayout mailBrd = new BorderLayout();
  JPanel contentPaneMail = new JPanel();

  // Menu File
  JMenu mailerFile = new JMenu();

  // Items for Menu File
  JMenuItem mailerSend = new JMenuItem();
  JMenuItem mailerFileName = new JMenuItem();
  JMenuItem mailerReset = new JMenuItem();
  JMenuItem mailerExit = new JMenuItem();

  // Menu Edit
  JMenu mailerEdit = new JMenu();

  // Items for Menu Edit
  JMenuItem mailerCut = new JMenuItem();
  JMenuItem mailerCopy = new JMenuItem();
  JMenuItem mailerPaste = new JMenuItem();
  JMenuItem mailerSelectAll = new JMenuItem();

  // ToolBar
  JToolBar mailerToolBar = new JToolBar();

  // Button to send email
  JButton btnSend = new JButton();

  // Pulsante per l' allegato
  JButton btnFile = new JButton();

  // Pulsante per resettare i campi
  JButton btnReset = new JButton();

  // Exit Button
  JButton btnClose = new JButton();

  // Cut
  JButton btnCut = new JButton();

  // Copy
  JButton btnCopy = new JButton();

  // Paste
  JButton btnPaste = new JButton();

  // Labels
  JLabel lblHost = new JLabel();
  JLabel lblFrom = new JLabel();
  JLabel lblSubject = new JLabel();
  JLabel lblFile = new JLabel();
  JPanel lblPnl = new JPanel();

  // TextFields
  JTextField txtHost = new JTextField();
  JTextField txtFrom = new JTextField();
  JTextField txtSubject = new JTextField();
  JTextField txtFile = new JTextField();
  JPanel txtPnl = new JPanel();

  BorderLayout mailBrdNorth = new BorderLayout();
  JPanel mailPnlNorth = new JPanel();

  // Text Area for the message
  JTextArea txtMessage = new JTextArea();

  String status;
  Border statusBorder;
  JLabel statusLabel = new JLabel();

  BorderLayout mailBrdSouth = new BorderLayout();
  JPanel mailPnlSouth = new JPanel();

  public Mailer() {

    contentPaneMail.setLayout(mailBrd);
    contentPaneMail.setSize(400, 500);
    contentPaneMail.setOpaque(true);
    contentPaneMail.add(mailPnlNorth, BorderLayout.NORTH);
    contentPaneMail.add(new JScrollPane(txtMessage), BorderLayout.CENTER);
    contentPaneMail.add(mailPnlSouth, BorderLayout.SOUTH);

  	// Proprietà della MenuBar
    mailerBorder = BorderFactory.createBevelBorder(BevelBorder.RAISED,
                                                   new Color(248, 254, 255),
                                                   Color.white,
						   new Color(121, 124, 136),
                                                   new Color(84, 86, 95));
    MailerMenuBar.setOpaque(true);
    MailerMenuBar.setBorder(mailerBorder);
    MailerMenuBar.add(mailerFile);
    MailerMenuBar.add(mailerEdit);

    mailerFile.setOpaque(true);
    mailerFile.setText(utils.getString("MailerMenu.file_label"));
    mailerFile.setMnemonic(utils.getMnemonic("MailerMenu.file_mnemonic"));
    mailerFile.add(mailerSend);
    mailerFile.add(mailerFileName);
    mailerFile.add(mailerReset);
    mailerFile.add(new JSeparator());
    mailerFile.add(mailerExit);

    mailerSend.setIcon(utils.createImageIcon16x16("Mail_generic.png"));
    mailerSend.setText(utils.getString("MailerMenu.file_send"));
    mailerSend.setMnemonic(utils.getMnemonic("MailerMenu.file_send_mnemonic"));
    mailerSend.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        sendMail();
      }
    });

    mailerFileName.setIcon(utils.createImageIcon16x16("Fileopen.png"));
    mailerFileName.setText(utils.getString("MailerMenu.file_attach"));
    mailerFileName.setMnemonic(utils.getMnemonic("MailerMenu.file_attach_mnemonic"));
    mailerFileName.addActionListener(new openFile());

    mailerReset.setIcon(utils.createImageIcon16x16("X.png"));
    mailerReset.setText(utils.getString("MailerMenu.file_reset"));
    mailerReset.setMnemonic(utils.getMnemonic("MailerMenu.file_reset_mnemonic"));
    mailerReset.addActionListener(new resetFields());

    mailerExit.setIcon(utils.createImageIcon16x16("Exit.png"));
    mailerExit.setText(utils.getString("MailerMenu.file_exit"));
    mailerExit.setMnemonic(utils.getMnemonic("MailerMenu.file_exit_mnemonic"));
    mailerExit.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        dispose();
      }
    });

    mailerEdit.setOpaque(true);
    mailerEdit.setText(utils.getString("MailerMenu.edit_label"));
    mailerEdit.setMnemonic(utils.getMnemonic("MailerMenu.edit_mnemonic"));
    mailerEdit.add(mailerCut);
    mailerEdit.add(mailerCopy);
    mailerEdit.add(mailerPaste);

    mailerCut.setIcon(utils.createImageIcon16x16("Editcut.png"));
    mailerCut.setText(utils.getString("MailerMenu.edit_cut"));
    mailerCut.setMnemonic(utils.getMnemonic("MailerMenu.edit_cut_mnemonic"));
    mailerCut.addActionListener(new DefaultEditorKit.CutAction());

    mailerCopy.setIcon(utils.createImageIcon16x16("Editcopy.png"));
    mailerCopy.setText(utils.getString("MailerMenu.edit_copy"));
    mailerCopy.setMnemonic(utils.getMnemonic("MailerMenu.edit_copy_mnemonic"));
    mailerCopy.addActionListener(new DefaultEditorKit.CopyAction());

    mailerPaste.setIcon(utils.createImageIcon16x16("Editpaste.png"));
    mailerPaste.setText(utils.getString("MailerMenu.edit_paste"));
    mailerPaste.setMnemonic(utils.getMnemonic("MailerMenu.edit_paste_mnemonic"));
    mailerPaste.addActionListener(new DefaultEditorKit.PasteAction());

    mailPnlNorth.setOpaque(true);
    mailPnlNorth.setLayout(mailBrdNorth);
    mailPnlNorth.add(mailerToolBar, BorderLayout.NORTH);
    mailPnlNorth.add(lblPnl, BorderLayout.WEST);
    mailPnlNorth.add(txtPnl, BorderLayout.CENTER);

    mailerToolBar.setOpaque(true);
    mailerToolBar.setBorder(BorderFactory.createEtchedBorder());
    mailerToolBar.add(btnSend);
    mailerToolBar.add(btnFile);
    mailerToolBar.add(btnReset);
    mailerToolBar.add(btnClose);
    mailerToolBar.add(btnCut);
    mailerToolBar.add(btnCopy);
    mailerToolBar.add(btnPaste);

    btnSend.setOpaque(true);
    btnSend.setBorder(BorderFactory.createEmptyBorder(4, 4, 4, 4));
    btnSend.setIcon(utils.createImageIcon24x24("Mail_send.png"));
    btnSend.setToolTipText(utils.getString("MailerMenu.file_send"));
    btnSend.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        sendMail();
      }
    });

    btnFile.setOpaque(true);
    btnFile.setBorder(BorderFactory.createEmptyBorder(4, 4, 4, 4));
    btnFile.setIcon(utils.createImageIcon24x24("Attach.png"));
    btnFile.setToolTipText(utils.getString("MailerMenu.file_attach"));
    btnFile.addActionListener(new openFile());

    btnReset.setOpaque(true);
    btnReset.setBorder(BorderFactory.createEmptyBorder(4, 4, 4, 4));
    btnReset.setIcon(utils.createImageIcon24x24("Redo.png"));
    btnReset.setToolTipText(utils.getString("MailerMenu.file_reset"));
    btnReset.addActionListener(new resetFields());

    btnClose.setOpaque(true);
    btnClose.setBorder(BorderFactory.createEmptyBorder(4, 4, 4, 4));
    btnClose.setIcon(utils.createImageIcon24x24("Exit.png"));
    btnClose.setToolTipText(utils.getString("MailerMenu.file_exit"));
    btnClose.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        dispose();
        Mailer mailer = null;
      }
    });

    btnCut.setOpaque(true);
    btnCut.setBorder(BorderFactory.createEmptyBorder(4, 4, 4, 4));
    btnCut.setIcon(utils.createImageIcon24x24("Editcut.png"));
    btnCut.setToolTipText(utils.getString("MailerMenu.edit_cut"));
    btnCut.addActionListener(new DefaultEditorKit.CutAction());

    btnCopy.setOpaque(true);
    btnCopy.setBorder(BorderFactory.createEmptyBorder(4, 4, 4, 4));
    btnCopy.setIcon(utils.createImageIcon24x24("Editcopy.png"));
    btnCopy.setToolTipText(utils.getString("MailerMenu.edit_copy"));
    btnCopy.addActionListener(new DefaultEditorKit.CopyAction());

    btnPaste.setOpaque(true);
    btnPaste.setBorder(BorderFactory.createEmptyBorder(4, 4, 4, 4));
    btnPaste.setIcon(utils.createImageIcon24x24("Editpaste.png"));
    btnPaste.setToolTipText(utils.getString("MailerMenu.edit_paste"));
    btnPaste.addActionListener(new DefaultEditorKit.PasteAction());

    lblPnl.setLayout(new GridLayout(0,1));
    lblPnl.add(lblHost);
    lblPnl.add(lblFrom);
    lblPnl.add(lblSubject);
    lblPnl.add(lblFile);

    lblHost.setText(utils.getString("Mailer.label_smtp") + " ");
    lblFrom.setText(utils.getString("Mailer.label_email") + " ");
    lblSubject.setText(utils.getString("Mailer.label_subject") + " ");
    lblFile.setText(utils.getString("Mailer.label_attach") + " ");

    txtPnl.setLayout(new GridLayout(0,1));
    txtPnl.add(txtHost);
    txtPnl.add(txtFrom);
    txtPnl.add(txtSubject);
    txtPnl.add(txtFile);

    String mail = conf.get("User.mail");
    String smtp = conf.get("User.smtp");

    txtHost.setToolTipText(utils.getString("Mailer.text_area_smtp"));
    txtHost.setText(smtp);
    txtFrom.setToolTipText(utils.getString("Mailer.text_area_email"));
    txtFrom.setText(mail);
    txtSubject.setToolTipText(utils.getString("Mailer.text_area_subject"));
    txtFile.setToolTipText(utils.getString("Mailer.text_area_attach"));

    mailPnlSouth.setOpaque(true);
    mailPnlSouth.setLayout(mailBrdSouth);
    mailPnlSouth.add(statusLabel, BorderLayout.SOUTH);

    statusBorder = BorderFactory.createBevelBorder(BevelBorder.LOWERED,
                                                   new Color(248, 254, 255),
                                                   Color.white,
                                                   new Color(121, 124, 136),
						   new Color(84, 86, 95));
    statusLabel.setOpaque(true);
    statusLabel.setBorder(statusBorder);
    statusLabel.setText(utils.getString("Mailer.status_label"));

    Image iconMail = Toolkit.getDefaultToolkit().getImage(getClass().getResource("/images/icons/16x16/Mail_generic.png"));

    this.setIconImage(iconMail);
    this.setSize(400, 500);
    this.setResizable(true);
    this.getContentPane().add(contentPaneMail, BorderLayout.CENTER);
    Dimension screenDim = Toolkit.getDefaultToolkit().getScreenSize();
    Rectangle frameDim = getBounds();
    this.setLocation((screenDim.width - frameDim.width) / 2,
                     (screenDim.height - frameDim.height) / 2);
    this.setTitle(titleMailer);
    this.setJMenuBar(MailerMenuBar);
    this.addWindowListener(new WindowAdapter() {
      public void windowClosing(WindowEvent e) {
        dispose();
        Mailer mailer = null;
      }
    });
    this.setVisible(true);
  }

  /**
   * Method to send the message
   */
  private void sendMail() {

    // Informations to send the message
    host = txtHost.getText();
    from = txtFrom.getText();
    subject = txtSubject.getText();
    messageText = txtMessage.getText();
    filename = txtFile.getText();

    // Create some properties and obtain the default sessio
    Properties props = System.getProperties();
      props.put("mail.host", host);
      props.put("mail.transport.protocol", "smtp");

    // Set debug for the Session to know what is
    // happening. Using the boolean value "false" we don't have echo about debug informations
    Session session = Session.getDefaultInstance(props, null);
      session.setDebug(sessionDebug);

    try {

      // Create a new MimeMessage
      MimeMessage msg = new MimeMessage(session);

      msg.setFrom(new InternetAddress(from));
      InternetAddress[] address = {new InternetAddress(to)};
      msg.setRecipients(Message.RecipientType.TO, address);
      msg.setSubject(subject);

      // Is there an attach?
      if (filename.length() != 0) {

        // First part of the message
        MimeBodyPart mbp1 = new MimeBodyPart();
        mbp1.setText(messageText);

        // Second part of the message
        MimeBodyPart mbp2 = new MimeBodyPart();

        // Attach the file
        FileDataSource fds = new FileDataSource(filename);
        mbp2.setDataHandler(new DataHandler(fds));
        mbp2.setFileName(fds.getName());

        // Create the Multipart
        Multipart mp = new MimeMultipart();
        mp.addBodyPart(mbp1);
        mp.addBodyPart(mbp2);

        // Add the Multipart to the message
        msg.setContent(mp);
     }
     else {
       // Attach does not exists
       msg.setText(messageText);
     }

      // Date: header
      msg.setSentDate(new Date());

      // Send the message
      Transport.send(msg);

      statusLabel.setText(utils.getString("Mailer.status_label_success"));
    }
    catch(MessagingException mex) {
      statusLabel.setText(utils.getString("Mailer.status_label_failed"));
      JOptionPane.showMessageDialog(null, utils.getString("Mailer.status_label_failed"),
                                    utils.getString("Messagebox.error_title"),
                                    JOptionPane.ERROR_MESSAGE);
      mex.printStackTrace();
    }
  }

  /**
   * ActionListeners
   */
  class openFile implements ActionListener {
    public void actionPerformed(ActionEvent e) {
      int returnVal = fileChooser.showOpenDialog(Mailer.this);

      if (returnVal == JFileChooser.APPROVE_OPTION) {
        File file = fileChooser.getSelectedFile();
        txtFile.setText(file.getPath());
      }
      else {
      }
    }
  }

  class resetFields implements ActionListener {
    public void actionPerformed(ActionEvent e) {
      // Resetta i campi
      txtHost.setText("");
      txtFrom.setText("");
      txtSubject.setText("");
      txtMessage.setText("");
      txtFile.setText("");
    }
  }
}

/**
 * End Mailer.
 */
