
/*==============================================================================
 *
 * (#)TableRenderer.java
 * created      2003/07/11
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.

 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *==============================================================================
 */

package com.miami.romeo.main.table;

import java.awt.*;
import java.util.*;
import java.io.*;

import javax.swing.*;
import javax.swing.table.*;
import javax.swing.border.*;

import com.miami.romeo.config.*;

/**
 * TableRenderer.<br>
 * Renderer for table cells.
 *
 * @author       $Author: Stefano Bolli
 * @version      $Revision: 1.3 $Date: 2003/10/31 00:27:07 $
 */
public class TableRenderer extends DefaultTableCellRenderer {
  Utils utils = new Utils();

  Color c;
  
  ImageIcon imgBookmark, imgRom, imgNoRom;

  String yes;

  /**
   * Constructor.
   *
   * @param c The table cell background color
   */
  public TableRenderer(Color c) {
    this.c           = c;
    this.imgBookmark = utils.createImageIcon16x16("Bookmark.png");
    this.imgRom      = utils.createImageIcon16x16("Rom.png");
    this.imgNoRom    = utils.createImageIcon16x16("NoRom.png");
    this.yes         = "Yes";
  }

  public Component getTableCellRendererComponent(JTable table, Object value,
                                                 boolean isSelected,
				                 boolean hasFocus,
						 int row, int column) {
    Component comp = super.getTableCellRendererComponent(table, value,
                                                         isSelected, hasFocus,
							 row, column);

    if (table.getColumnName(column).equals(
                                        utils.getString("Table.column_icon"))) {
      ((JLabel)comp).setHorizontalAlignment(JLabel.CENTER);

      if (value.toString().equals("-"))
        ((JLabel)comp).setIcon(null);
      else
        ((JLabel)comp).setIcon(new ImageIcon(value.toString()));

      ((JLabel)comp).setText("");
    }
    else if (table.getColumnName(column).equals(
                                    utils.getString("Table.column_favorite"))) {
      ((JLabel)comp).setHorizontalAlignment(JLabel.CENTER);

      if (value.toString().endsWith("Yes"))
        ((JLabel)comp).setIcon(imgBookmark);
      else
        ((JLabel)comp).setIcon(null);

      ((JLabel)comp).setText("");
    }
    else if (table.getColumnName(column).equals(
                                utils.getString("Table.column_availability"))) {
      ((JLabel)comp).setHorizontalAlignment(JLabel.CENTER);

      if (value.toString().endsWith(yes))
        ((JLabel)comp).setIcon(imgRom);
      else
        ((JLabel)comp).setIcon(imgNoRom);

      ((JLabel)comp).setText("");
    }
    else {
      ((JLabel)comp).setHorizontalAlignment(JLabel.LEFT);
      
      ((JLabel)comp).setIcon(null);
      
      // Set font
      Config config = new Config(new File(System.getProperty("user.home") + 
                                 File.separator + ".romeo4xmame" + 
				 File.separator + "Romeo.ini"));
      
      // Does the user wanna a new font?
      String fontName = config.get("Table.font");
      int fontSize = config.getInt("Table.font_size");
      int fontStyle = config.getInt("Table.font_style");

      if (!fontName.equals(""))
        ((JLabel)comp).setFont(new Font(fontName, fontStyle, fontSize));
      else
        ((JLabel)comp).setFont(getFont());
      
      ((JLabel)comp).setText((value == null) ? "" : value.toString());
    }


    if (isSelected) {
      comp.setBackground(table.getSelectionBackground());
      comp.setForeground(table.getSelectionForeground());
    }
    else {
      comp.setBackground(c);

      int r = c.getRed();
      int g = c.getGreen();
      int b = c.getBlue();

      if(r > 240 || g > 240) {
        comp.setForeground(Color.black);
      } else {
        comp.setForeground(Color.white);
      }
    }
    
    return comp;
  }
}
